@@ -1,8 +1,8 @@
 var searchData=
 [
   ['wait_0',['wait',['../a00762.html#a9d777609e20094558e76e528c1b15e2e',1,'osl::Condition::wait()'],['../a00878.html#ac51d11d3729116f912934ffefe9ad2d6',1,'osl::Thread::wait()']]],
-  ['weak_2ehxx_1',['weak.hxx',['../a00425.html',1,'']]],
-  ['weakagg_2ehxx_2',['weakagg.hxx',['../a00428.html',1,'']]],
+  ['weak_2ehxx_1',['weak.hxx',['../a00338.html',1,'']]],
+  ['weakagg_2ehxx_2',['weakagg.hxx',['../a00470.html',1,'']]],
   ['weakaggcomponentimplhelper1_3',['WeakAggComponentImplHelper1',['../a01050.html',1,'cppu::WeakAggComponentImplHelper1&lt; Ifc1 &gt;'],['../a01050.html#a539345db80771d0ee7e8845f2c022f57',1,'cppu::WeakAggComponentImplHelper1::WeakAggComponentImplHelper1()']]],
   ['weakaggcomponentimplhelper10_4',['WeakAggComponentImplHelper10',['../a01074.html',1,'cppu::WeakAggComponentImplHelper10&lt; Ifc1, Ifc2, Ifc3, Ifc4, Ifc5, Ifc6, Ifc7, Ifc8, Ifc9, Ifc10 &gt;'],['../a01074.html#a93425dffcbdc8953790144cfb20f18d4',1,'cppu::WeakAggComponentImplHelper10::WeakAggComponentImplHelper10()']]],
   ['weakaggcomponentimplhelper11_5',['WeakAggComponentImplHelper11',['../a01098.html',1,'cppu::WeakAggComponentImplHelper11&lt; Ifc1, Ifc2, Ifc3, Ifc4, Ifc5, Ifc6, Ifc7, Ifc8, Ifc9, Ifc10, Ifc11 &gt;'],['../a01098.html#adbc203e7235e02bf44917c243de7b126',1,'cppu::WeakAggComponentImplHelper11::WeakAggComponentImplHelper11()']]],
@@ -53,12 +53,14 @@ var searchData=
   ['weakimplhelper7_50',['WeakImplHelper7',['../a01738.html',1,'cppu']]],
   ['weakimplhelper8_51',['WeakImplHelper8',['../a01778.html',1,'cppu']]],
   ['weakimplhelper9_52',['WeakImplHelper9',['../a01818.html',1,'cppu']]],
-  ['weakref_2ehxx_53',['weakref.hxx',['../a00455.html',1,'']]],
+  ['weakref_2ehxx_53',['weakref.hxx',['../a00362.html',1,'']]],
   ['weakreference_54',['WeakReference',['../a01958.html',1,'com::sun::star::uno::WeakReference&lt; interface_type &gt;'],['../a01958.html#a81c6ea589549e79c3f826cccee911c96',1,'com::sun::star::uno::WeakReference::WeakReference()'],['../a01958.html#acaf481b6213b80c061daf01407e848c2',1,'com::sun::star::uno::WeakReference::WeakReference(const Reference&lt; interface_type &gt; &amp;rRef)']]],
-  ['weakreferencehelper_55',['WeakReferenceHelper',['../a01954.html',1,'com::sun::star::uno::WeakReferenceHelper'],['../a01954.html#a4dee9f907ba07214463819d756726182',1,'com::sun::star::uno::WeakReferenceHelper::WeakReferenceHelper(const WeakReferenceHelper &amp;rWeakRef)'],['../a01954.html#a01c610f0b6dc26c7a66caf6878a51bd5',1,'com::sun::star::uno::WeakReferenceHelper::WeakReferenceHelper(const css::uno::Reference&lt; css::uno::XInterface &gt; &amp;xInt)'],['../a01954.html#aca4edf16679e5f81ed2bef368a4f4d63',1,'com::sun::star::uno::WeakReferenceHelper::WeakReferenceHelper()']]],
-  ['write_56',['write',['../a00790.html#aaff12dea186b6242260ae8309b6127d0',1,'osl::File::write()'],['../a00834.html#a30cdb06bcd089b1187dc39e88df8caf3',1,'osl::StreamPipe::write()'],['../a00862.html#a728d093e0c39a2c5350b355d85a84be8',1,'osl::StreamSocket::write()']]],
-  ['writebool_57',['writeBool',['../a00842.html#a2e91013ff0f6161016cb4dbbd3bf5e11',1,'osl::Profile']]],
-  ['writeident_58',['writeIdent',['../a00842.html#af29f27877b179547100689985fd8e14a',1,'osl::Profile']]],
-  ['writesharedlibcomponentinfo_59',['writeSharedLibComponentInfo',['../a00537.html#ab095981eb186bd687f35a0550d1c3ee9',1,'cppu']]],
-  ['writestring_60',['writeString',['../a00842.html#a131f4dc8d4f6538e809da5265742cc37',1,'osl::Profile']]]
+  ['weakreferencehelper_55',['WeakReferenceHelper',['../a01954.html',1,'com::sun::star::uno::WeakReferenceHelper'],['../a01954.html#aca4edf16679e5f81ed2bef368a4f4d63',1,'com::sun::star::uno::WeakReferenceHelper::WeakReferenceHelper()'],['../a01954.html#a4dee9f907ba07214463819d756726182',1,'com::sun::star::uno::WeakReferenceHelper::WeakReferenceHelper(const WeakReferenceHelper &amp;rWeakRef)'],['../a01954.html#a01c610f0b6dc26c7a66caf6878a51bd5',1,'com::sun::star::uno::WeakReferenceHelper::WeakReferenceHelper(const css::uno::Reference&lt; css::uno::XInterface &gt; &amp;xInt)']]],
+  ['which_20fields_20to_20retrieve_20by_20osl_5fgetfilestatus_56',['Flags specifying which fields to retrieve by osl_getFileStatus',['../a00523.html',1,'']]],
+  ['which_20fields_20to_20retrieve_20by_20osl_5fgetvolumeinfo_57',['Flags specifying which fields to retrieve by osl_getVolumeInfo',['../a00525.html',1,'']]],
+  ['write_58',['write',['../a00790.html#aaff12dea186b6242260ae8309b6127d0',1,'osl::File::write()'],['../a00834.html#a30cdb06bcd089b1187dc39e88df8caf3',1,'osl::StreamPipe::write()'],['../a00862.html#a728d093e0c39a2c5350b355d85a84be8',1,'osl::StreamSocket::write()']]],
+  ['writebool_59',['writeBool',['../a00842.html#a2e91013ff0f6161016cb4dbbd3bf5e11',1,'osl::Profile']]],
+  ['writeident_60',['writeIdent',['../a00842.html#af29f27877b179547100689985fd8e14a',1,'osl::Profile']]],
+  ['writesharedlibcomponentinfo_61',['writeSharedLibComponentInfo',['../a00537.html#ab095981eb186bd687f35a0550d1c3ee9',1,'cppu']]],
+  ['writestring_62',['writeString',['../a00842.html#a131f4dc8d4f6538e809da5265742cc37',1,'osl::Profile']]]
 ];
